@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Acme::MetaSyntactic::MultiList;
 our @ISA = qw( Acme::MetaSyntactic::MultiList );
-our $VERSION = '1.000';
+our $VERSION = '1.001';
 
 =encoding iso-8859-1
 
@@ -999,6 +999,20 @@ The winners are:
  2012   Physics     David J. Wineland
  2012   Physics     Serge Haroche
 
+ 2013   Chemistry   Arieh Warshel
+ 2013   Chemistry   Martin Karplus
+ 2013   Chemistry   Michael Levitt
+ 2013   Economics   Eugene F. Fama
+ 2013   Economics   Lars Peter Hansen
+ 2013   Economics   Robert J. Shiller
+ 2013   Literature  Alice Munro
+ 2013   Medecine    James E. Rothman
+ 2013   Medecine    Randy W. Schekman
+ 2013   Medecine    Thomas C. Sdhof
+ 2013   Peace       Organization for the Prohibition of Chemical Weapons
+ 2013   Physics     Franois Englert
+ 2013   Physics     Peter Higgs
+
 =cut
 
         next unless $line =~ /^\s+(\d+)\s+(\w+)\s+(.*)/;
@@ -1033,6 +1047,13 @@ Abigail
 
 =item *
 
+2013-10-13 - v1.001
+
+Updated with the Nobel prizes for 2013, and
+published in Acme-MetaSyntactic-Themes version 1.037.
+
+=item *
+
 2012-10-15 - v1.000
 
 Updated with the Nobel prizes for 2012, and
